@@ -31,13 +31,13 @@ from glance.common import config
 from glance.common import exception
 from glance import context
 from glance.db.sqlalchemy import api as db_api
-from glance.db.sqlalchemy import models as db_models
 from glance.openstack.common import timeutils
 from glance.openstack.common import uuidutils
 import glance.registry.client.v2.api as rapi
 from glance.registry.client.v2.api import client as rclient
 from glance.registry.api import v2 as rserver
 from glance.tests.unit import base
+from glance.tests import utils as test_utils
 
 
 _gen_uuid = uuidutils.generate_uuid
@@ -49,7 +49,8 @@ UUID2 = _gen_uuid()
 config.parse_args(args=[])
 
 
-class TestRegistryV2Client(base.IsolatedUnitTest):
+class TestRegistryV2Client(base.IsolatedUnitTest,
+                           test_utils.RegistryAPIMixIn):
     """
     Test proper actions made for both valid and invalid requests
     against a Registry service
@@ -65,35 +66,18 @@ class TestRegistryV2Client(base.IsolatedUnitTest):
         db_api.setup_db_env()
         db_api.get_engine()
         self.context = context.RequestContext(is_admin=True)
+        uuid1_time = timeutils.utcnow()
+        uuid2_time = uuid1_time + datetime.timedelta(seconds=5)
         self.FIXTURES = [
-            {'id': UUID1,
-             'name': 'fake image #1',
-             'status': 'active',
-             'disk_format': 'ami',
-             'container_format': 'ami',
-             'is_public': False,
-             'created_at': timeutils.utcnow(),
-             'updated_at': timeutils.utcnow(),
-             'deleted_at': None,
-             'deleted': False,
-             'checksum': None,
-             'size': 13,
-             'location': "swift://user:passwd@acct/container/obj.tar.0",
-             'properties': {'type': 'kernel'}},
-            {'id': UUID2,
-             'name': 'fake image #2',
-             'status': 'active',
-             'disk_format': 'vhd',
-             'container_format': 'ovf',
-             'is_public': True,
-             'created_at': timeutils.utcnow(),
-             'updated_at': timeutils.utcnow(),
-             'deleted_at': None,
-             'deleted': False,
-             'checksum': None,
-             'size': 19,
-             'location': "file:///tmp/glance-tests/2",
-             'properties': {}}]
+            self.get_extra_fixture(
+                id=UUID1, name='fake image #1', is_public=False,
+                disk_format='ami', container_format='ami', size=13,
+                location="swift://user:passwd@acct/container/obj.tar.0",
+                properties={'type': 'kernel'}, created_at=uuid1_time),
+            self.get_extra_fixture(id=UUID2, name='fake image #2',
+                                   properties={}, size=19,
+                                   location="file:///tmp/glance-tests/2",
+                                   created_at=uuid2_time)]
         self.destroy_fixtures()
         self.create_fixtures()
         self.client = rclient.RegistryClient("0.0.0.0")
@@ -103,15 +87,6 @@ class TestRegistryV2Client(base.IsolatedUnitTest):
         super(TestRegistryV2Client, self).tearDown()
         self.destroy_fixtures()
 
-    def create_fixtures(self):
-        for fixture in self.FIXTURES:
-            db_api.image_create(self.context, fixture)
-
-    def destroy_fixtures(self):
-        # Easiest to just drop the models and re-create them...
-        db_models.unregister_models(db_api._ENGINE)
-        db_models.register_models(db_api._ENGINE)
-
     def test_image_get_index(self):
         """Test correct set of public image returned"""
         images = self.client.image_get_all()
@@ -119,18 +94,8 @@ class TestRegistryV2Client(base.IsolatedUnitTest):
 
     def test_create_image_with_null_min_disk_min_ram(self):
         UUID3 = _gen_uuid()
-        extra_fixture = {
-            'id': UUID3,
-            'status': 'active',
-            'is_public': True,
-            'disk_format': 'vhd',
-            'container_format': 'ovf',
-            'name': 'asdf',
-            'size': 19,
-            'checksum': None,
-            'min_disk': None,
-            'min_ram': None,
-        }
+        extra_fixture = self.get_fixture(id=UUID3, name='asdf', min_disk=None,
+                                         min_ram=None)
         db_api.image_create(self.context, extra_fixture)
         image = self.client.image_get(image_id=UUID3)
         self.assertEqual(0, image["min_ram"])
@@ -143,36 +108,19 @@ class TestRegistryV2Client(base.IsolatedUnitTest):
         ascending order.
         """
         UUID3 = _gen_uuid()
-        extra_fixture = {'id': UUID3,
-                         'status': 'active',
-                         'is_public': True,
-                         'disk_format': 'vhd',
-                         'container_format': 'ovf',
-                         'name': 'asdf',
-                         'size': 19,
-                         'checksum': None}
+        extra_fixture = self.get_fixture(id=UUID3, name='asdf')
 
         db_api.image_create(self.context, extra_fixture)
 
         UUID4 = _gen_uuid()
-        extra_fixture = {'id': UUID4,
-                         'status': 'active',
-                         'is_public': True,
-                         'disk_format': 'vhd',
-                         'container_format': 'ovf',
-                         'name': 'xyz',
-                         'size': 20,
-                         'checksum': None}
+        extra_fixture = self.get_fixture(id=UUID4, name='xyz')
 
         db_api.image_create(self.context, extra_fixture)
 
         images = self.client.image_get_all(sort_key='name', sort_dir='asc')
 
-        self.assertEquals(len(images), 4)
-        self.assertEquals(images[0]['id'], UUID3)
-        self.assertEquals(images[1]['id'], UUID1)
-        self.assertEquals(images[2]['id'], UUID2)
-        self.assertEquals(images[3]['id'], UUID4)
+        self.assertEqualImages(images, (UUID3, UUID1, UUID2, UUID4),
+                               unjsonify=False)
 
     def test_get_index_sort_status_desc(self):
         """
@@ -180,37 +128,24 @@ class TestRegistryV2Client(base.IsolatedUnitTest):
         public images sorted alphabetically by status in
         descending order.
         """
+        uuid4_time = timeutils.utcnow() + datetime.timedelta(seconds=10)
+
         UUID3 = _gen_uuid()
-        extra_fixture = {'id': UUID3,
-                         'status': 'queued',
-                         'is_public': True,
-                         'disk_format': 'vhd',
-                         'container_format': 'ovf',
-                         'name': 'asdf',
-                         'size': 19,
-                         'checksum': None}
+        extra_fixture = self.get_fixture(id=UUID3, name='asdf',
+                                         status='queued')
 
         db_api.image_create(self.context, extra_fixture)
 
         UUID4 = _gen_uuid()
-        extra_fixture = {'id': UUID4,
-                         'status': 'active',
-                         'is_public': True,
-                         'disk_format': 'vhd',
-                         'container_format': 'ovf',
-                         'name': 'xyz',
-                         'size': 20,
-                         'checksum': None}
+        extra_fixture = self.get_fixture(id=UUID4, name='xyz',
+                                         created_at=uuid4_time)
 
         db_api.image_create(self.context, extra_fixture)
 
         images = self.client.image_get_all(sort_key='status', sort_dir='desc')
 
-        self.assertEquals(len(images), 4)
-        self.assertEquals(images[0]['id'], UUID3)
-        self.assertEquals(images[1]['id'], UUID4)
-        self.assertEquals(images[2]['id'], UUID2)
-        self.assertEquals(images[3]['id'], UUID1)
+        self.assertEqualImages(images, (UUID3, UUID4, UUID2, UUID1),
+                               unjsonify=False)
 
     def test_get_index_sort_disk_format_asc(self):
         """
@@ -219,37 +154,23 @@ class TestRegistryV2Client(base.IsolatedUnitTest):
         ascending order.
         """
         UUID3 = _gen_uuid()
-        extra_fixture = {'id': UUID3,
-                         'status': 'active',
-                         'is_public': True,
-                         'disk_format': 'ami',
-                         'container_format': 'ami',
-                         'name': 'asdf',
-                         'size': 19,
-                         'checksum': None}
+        extra_fixture = self.get_fixture(id=UUID3, name='asdf',
+                                         disk_format='ami',
+                                         container_format='ami')
 
         db_api.image_create(self.context, extra_fixture)
 
         UUID4 = _gen_uuid()
-        extra_fixture = {'id': UUID4,
-                         'status': 'active',
-                         'is_public': True,
-                         'disk_format': 'vdi',
-                         'container_format': 'ovf',
-                         'name': 'xyz',
-                         'size': 20,
-                         'checksum': None}
+        extra_fixture = self.get_fixture(id=UUID4, name='xyz',
+                                         disk_format='vdi')
 
         db_api.image_create(self.context, extra_fixture)
 
         images = self.client.image_get_all(sort_key='disk_format',
                                            sort_dir='asc')
 
-        self.assertEquals(len(images), 4)
-        self.assertEquals(images[0]['id'], UUID1)
-        self.assertEquals(images[1]['id'], UUID3)
-        self.assertEquals(images[2]['id'], UUID4)
-        self.assertEquals(images[3]['id'], UUID2)
+        self.assertEqualImages(images, (UUID1, UUID3, UUID4, UUID2),
+                               unjsonify=False)
 
     def test_get_index_sort_container_format_desc(self):
         """
@@ -258,37 +179,24 @@ class TestRegistryV2Client(base.IsolatedUnitTest):
         descending order.
         """
         UUID3 = _gen_uuid()
-        extra_fixture = {'id': UUID3,
-                         'status': 'active',
-                         'is_public': True,
-                         'disk_format': 'ami',
-                         'container_format': 'ami',
-                         'name': 'asdf',
-                         'size': 19,
-                         'checksum': None}
+        extra_fixture = self.get_fixture(id=UUID3, name='asdf',
+                                         disk_format='ami',
+                                         container_format='ami')
 
         db_api.image_create(self.context, extra_fixture)
 
         UUID4 = _gen_uuid()
-        extra_fixture = {'id': UUID4,
-                         'status': 'active',
-                         'is_public': True,
-                         'disk_format': 'iso',
-                         'container_format': 'bare',
-                         'name': 'xyz',
-                         'size': 20,
-                         'checksum': None}
+        extra_fixture = self.get_fixture(id=UUID4, name='xyz',
+                                         disk_format='iso',
+                                         container_format='bare')
 
         db_api.image_create(self.context, extra_fixture)
 
         images = self.client.image_get_all(sort_key='container_format',
                                            sort_dir='desc')
 
-        self.assertEquals(len(images), 4)
-        self.assertEquals(images[0]['id'], UUID2)
-        self.assertEquals(images[1]['id'], UUID4)
-        self.assertEquals(images[2]['id'], UUID3)
-        self.assertEquals(images[3]['id'], UUID1)
+        self.assertEqualImages(images, (UUID2, UUID4, UUID3, UUID1),
+                               unjsonify=False)
 
     def test_get_index_sort_size_asc(self):
         """
@@ -296,181 +204,106 @@ class TestRegistryV2Client(base.IsolatedUnitTest):
         public images sorted by size in ascending order.
         """
         UUID3 = _gen_uuid()
-        extra_fixture = {'id': UUID3,
-                         'status': 'active',
-                         'is_public': True,
-                         'disk_format': 'ami',
-                         'container_format': 'ami',
-                         'name': 'asdf',
-                         'size': 100,
-                         'checksum': None}
+        extra_fixture = self.get_fixture(id=UUID3, name='asdf',
+                                         disk_format='ami',
+                                         container_format='ami', size=100)
 
         db_api.image_create(self.context, extra_fixture)
 
         UUID4 = _gen_uuid()
-        extra_fixture = {'id': UUID4,
-                         'status': 'active',
-                         'is_public': True,
-                         'disk_format': 'iso',
-                         'container_format': 'bare',
-                         'name': 'xyz',
-                         'size': 2,
-                         'checksum': None}
+        extra_fixture = self.get_fixture(id=UUID4, name='asdf',
+                                         disk_format='iso',
+                                         container_format='bare', size=2)
 
         db_api.image_create(self.context, extra_fixture)
 
         images = self.client.image_get_all(sort_key='size', sort_dir='asc')
 
-        self.assertEquals(len(images), 4)
-        self.assertEquals(images[0]['id'], UUID4)
-        self.assertEquals(images[1]['id'], UUID1)
-        self.assertEquals(images[2]['id'], UUID2)
-        self.assertEquals(images[3]['id'], UUID3)
+        self.assertEqualImages(images, (UUID4, UUID1, UUID2, UUID3),
+                               unjsonify=False)
 
     def test_get_index_sort_created_at_asc(self):
         """
         Tests that the registry API returns list of
         public images sorted by created_at in ascending order.
         """
-        now = timeutils.utcnow()
-        time1 = now + datetime.timedelta(seconds=5)
-        time2 = now
+        uuid4_time = timeutils.utcnow() + datetime.timedelta(seconds=10)
+        uuid3_time = uuid4_time + datetime.timedelta(seconds=5)
 
         UUID3 = _gen_uuid()
-        extra_fixture = {'id': UUID3,
-                         'status': 'active',
-                         'is_public': True,
-                         'disk_format': 'vhd',
-                         'container_format': 'ovf',
-                         'name': 'new name! #123',
-                         'size': 19,
-                         'checksum': None,
-                         'created_at': time1}
+        extra_fixture = self.get_fixture(id=UUID3, created_at=uuid3_time)
 
         db_api.image_create(self.context, extra_fixture)
 
         UUID4 = _gen_uuid()
-        extra_fixture = {'id': UUID4,
-                         'status': 'active',
-                         'is_public': True,
-                         'disk_format': 'vhd',
-                         'container_format': 'ovf',
-                         'name': 'new name! #123',
-                         'size': 20,
-                         'checksum': None,
-                         'created_at': time2}
+        extra_fixture = self.get_fixture(id=UUID4, created_at=uuid4_time)
 
         db_api.image_create(self.context, extra_fixture)
 
         images = self.client.image_get_all(sort_key='created_at',
                                            sort_dir='asc')
 
-        self.assertEquals(len(images), 4)
-        self.assertEquals(images[0]['id'], UUID1)
-        self.assertEquals(images[1]['id'], UUID2)
-        self.assertEquals(images[2]['id'], UUID4)
-        self.assertEquals(images[3]['id'], UUID3)
+        self.assertEqualImages(images, (UUID1, UUID2, UUID4, UUID3),
+                               unjsonify=False)
 
     def test_get_index_sort_updated_at_desc(self):
         """
         Tests that the registry API returns list of
         public images sorted by updated_at in descending order.
         """
-        now = timeutils.utcnow()
-        time1 = now + datetime.timedelta(seconds=5)
-        time2 = now
+        uuid4_time = timeutils.utcnow() + datetime.timedelta(seconds=10)
+        uuid3_time = uuid4_time + datetime.timedelta(seconds=5)
 
         UUID3 = _gen_uuid()
-        extra_fixture = {'id': UUID3,
-                         'status': 'active',
-                         'is_public': True,
-                         'disk_format': 'vhd',
-                         'container_format': 'ovf',
-                         'name': 'new name! #123',
-                         'size': 19,
-                         'checksum': None,
-                         'created_at': None,
-                         'updated_at': time1}
+        extra_fixture = self.get_fixture(id=UUID3, created_at=None,
+                                         updated_at=uuid3_time)
 
         db_api.image_create(self.context, extra_fixture)
 
         UUID4 = _gen_uuid()
-        extra_fixture = {'id': UUID4,
-                         'status': 'active',
-                         'is_public': True,
-                         'disk_format': 'vhd',
-                         'container_format': 'ovf',
-                         'name': 'new name! #123',
-                         'size': 20,
-                         'checksum': None,
-                         'created_at': None,
-                         'updated_at': time2}
+        extra_fixture = self.get_fixture(id=UUID4, created_at=None,
+                                         updated_at=uuid4_time)
 
         db_api.image_create(self.context, extra_fixture)
 
         images = self.client.image_get_all(sort_key='updated_at',
                                            sort_dir='desc')
 
-        self.assertEquals(len(images), 4)
-        self.assertEquals(images[0]['id'], UUID3)
-        self.assertEquals(images[1]['id'], UUID4)
-        self.assertEquals(images[2]['id'], UUID2)
-        self.assertEquals(images[3]['id'], UUID1)
+        self.assertEqualImages(images, (UUID3, UUID4, UUID2, UUID1),
+                               unjsonify=False)
 
     def test_image_get_index_marker(self):
         """Test correct set of images returned with marker param."""
+        uuid4_time = timeutils.utcnow() + datetime.timedelta(seconds=10)
+        uuid3_time = uuid4_time + datetime.timedelta(seconds=5)
+
         UUID3 = _gen_uuid()
-        extra_fixture = {'id': UUID3,
-                         'status': 'saving',
-                         'is_public': True,
-                         'disk_format': 'vhd',
-                         'container_format': 'ovf',
-                         'name': 'new name! #123',
-                         'size': 19,
-                         'checksum': None}
+        extra_fixture = self.get_fixture(id=UUID3, name='new name! #123',
+                                         status='saving',
+                                         created_at=uuid3_time)
 
         db_api.image_create(self.context, extra_fixture)
 
         UUID4 = _gen_uuid()
-        extra_fixture = {'id': UUID4,
-                         'status': 'saving',
-                         'is_public': True,
-                         'disk_format': 'vhd',
-                         'container_format': 'ovf',
-                         'name': 'new name! #125',
-                         'size': 19,
-                         'checksum': None}
+        extra_fixture = self.get_fixture(id=UUID4, name='new name! #125',
+                                         status='saving',
+                                         created_at=uuid4_time)
 
         db_api.image_create(self.context, extra_fixture)
 
-        images = self.client.image_get_all(marker=UUID4)
+        images = self.client.image_get_all(marker=UUID3)
 
-        self.assertEquals(len(images), 3)
-        self.assertEquals(images[0]['id'], UUID3)
-        self.assertEquals(images[1]['id'], UUID2)
-        self.assertEquals(images[2]['id'], UUID1)
+        self.assertEqualImages(images, (UUID4, UUID2, UUID1), unjsonify=False)
 
     def test_image_get_index_limit(self):
         """Test correct number of images returned with limit param."""
-        extra_fixture = {'id': _gen_uuid(),
-                         'status': 'saving',
-                         'is_public': True,
-                         'disk_format': 'vhd',
-                         'container_format': 'ovf',
-                         'name': 'new name! #123',
-                         'size': 19,
-                         'checksum': None}
+        extra_fixture = self.get_fixture(id=_gen_uuid(), name='new name! #123',
+                                         status='saving')
 
         db_api.image_create(self.context, extra_fixture)
 
-        extra_fixture = {'id': _gen_uuid(),
-                         'status': 'saving',
-                         'is_public': True,
-                         'disk_format': 'vhd',
-                         'container_format': 'ovf',
-                         'name': 'new name! #125',
-                         'size': 19,
-                         'checksum': None}
+        extra_fixture = self.get_fixture(id=_gen_uuid(), name='new name! #125',
+                                         status='saving')
 
         db_api.image_create(self.context, extra_fixture)
 
@@ -479,56 +312,36 @@ class TestRegistryV2Client(base.IsolatedUnitTest):
 
     def test_image_get_index_marker_limit(self):
         """Test correct set of images returned with marker/limit params."""
+        uuid4_time = timeutils.utcnow() + datetime.timedelta(seconds=10)
+        uuid3_time = uuid4_time + datetime.timedelta(seconds=5)
+
         UUID3 = _gen_uuid()
-        extra_fixture = {'id': UUID3,
-                         'status': 'saving',
-                         'is_public': True,
-                         'disk_format': 'vhd',
-                         'container_format': 'ovf',
-                         'name': 'new name! #123',
-                         'size': 19,
-                         'checksum': None}
+        extra_fixture = self.get_fixture(id=UUID3, name='new name! #123',
+                                         status='saving',
+                                         created_at=uuid3_time)
 
         db_api.image_create(self.context, extra_fixture)
 
         UUID4 = _gen_uuid()
-        extra_fixture = {'id': UUID4,
-                         'status': 'saving',
-                         'is_public': True,
-                         'disk_format': 'vhd',
-                         'container_format': 'ovf',
-                         'name': 'new name! #125',
-                         'size': 19,
-                         'checksum': None}
+        extra_fixture = self.get_fixture(id=UUID4, name='new name! #125',
+                                         status='saving',
+                                         created_at=uuid4_time)
 
         db_api.image_create(self.context, extra_fixture)
 
-        images = self.client.image_get_all(marker=UUID3, limit=1)
+        images = self.client.image_get_all(marker=UUID4, limit=1)
 
-        self.assertEquals(len(images), 1)
-        self.assertEquals(images[0]['id'], UUID2)
+        self.assertEqualImages(images, (UUID2,), unjsonify=False)
 
     def test_image_get_index_limit_None(self):
         """Test correct set of images returned with limit param == None."""
-        extra_fixture = {'id': _gen_uuid(),
-                         'status': 'saving',
-                         'is_public': True,
-                         'disk_format': 'vhd',
-                         'container_format': 'ovf',
-                         'name': 'new name! #123',
-                         'size': 19,
-                         'checksum': None}
+        extra_fixture = self.get_fixture(id=_gen_uuid(), name='new name! #123',
+                                         status='saving')
 
         db_api.image_create(self.context, extra_fixture)
 
-        extra_fixture = {'id': _gen_uuid(),
-                         'status': 'saving',
-                         'is_public': True,
-                         'disk_format': 'vhd',
-                         'container_format': 'ovf',
-                         'name': 'new name! #125',
-                         'size': 19,
-                         'checksum': None}
+        extra_fixture = self.get_fixture(id=_gen_uuid(), name='new name! #125',
+                                         status='saving')
 
         db_api.image_create(self.context, extra_fixture)
 
@@ -540,14 +353,7 @@ class TestRegistryV2Client(base.IsolatedUnitTest):
         Test correct set of public, name-filtered image returned. This
         is just a sanity check, we test the details call more in-depth.
         """
-        extra_fixture = {'id': _gen_uuid(),
-                         'status': 'active',
-                         'is_public': True,
-                         'disk_format': 'vhd',
-                         'container_format': 'ovf',
-                         'name': 'new name! #123',
-                         'size': 19,
-                         'checksum': None}
+        extra_fixture = self.get_fixture(id=_gen_uuid(), name='new name! #123')
 
         db_api.image_create(self.context, extra_fixture)
 
@@ -559,15 +365,8 @@ class TestRegistryV2Client(base.IsolatedUnitTest):
 
     def test_image_get_is_public_v2(self):
         """Tests that a detailed call can be filtered by a property"""
-        extra_fixture = {'id': _gen_uuid(),
-                         'status': 'saving',
-                         'is_public': True,
-                         'disk_format': 'vhd',
-                         'container_format': 'ovf',
-                         'name': 'new name! #123',
-                         'size': 19,
-                         'checksum': None,
-                         'properties': {'is_public': 'avalue'}}
+        extra_fixture = self.get_fixture(id=_gen_uuid(), status='saving',
+                                         properties={'is_public': 'avalue'})
 
         context = copy.copy(self.context)
         db_api.image_create(context, extra_fixture)
@@ -581,13 +380,9 @@ class TestRegistryV2Client(base.IsolatedUnitTest):
 
     def test_image_get(self):
         """Tests that the detailed info about an image returned"""
-        fixture = {'id': UUID1,
-                   'name': 'fake image #1',
-                   'is_public': False,
-                   'disk_format': 'ami',
-                   'container_format': 'ami',
-                   'status': 'active',
-                   'size': 13}
+        fixture = self.get_fixture(id=UUID1, name='fake image #1',
+                                   is_public=False, size=13,
+                                   disk_format='ami', container_format='ami')
 
         data = self.client.image_get(image_id=UUID1)
 
@@ -606,14 +401,7 @@ class TestRegistryV2Client(base.IsolatedUnitTest):
 
     def test_image_create_basic(self):
         """Tests that we can add image metadata and returns the new id"""
-        fixture = {
-            'name': 'fake public image',
-            'is_public': True,
-            'disk_format': 'vmdk',
-            'container_format': 'ovf',
-            'size': 19,
-            'status': 'active',
-        }
+        fixture = self.get_fixture()
 
         new_image = self.client.image_create(values=fixture)
 
@@ -629,14 +417,8 @@ class TestRegistryV2Client(base.IsolatedUnitTest):
 
     def test_image_create_with_properties(self):
         """Tests that we can add image metadata with properties"""
-        fixture = {'name': 'fake public image',
-                   'is_public': True,
-                   'disk_format': 'vmdk',
-                   'container_format': 'ovf',
-                   'size': 19,
-                   'status': 'active',
-                   'location': "file:///tmp/glance-tests/2",
-                   'properties': {'distro': 'Ubuntu 10.04 LTS'}}
+        fixture = self.get_fixture(location="file:///tmp/glance-tests/2",
+                                   properties={'distro': 'Ubuntu 10.04 LTS'})
 
         new_image = self.client.image_create(values=fixture)
 
@@ -656,16 +438,8 @@ class TestRegistryV2Client(base.IsolatedUnitTest):
 
     def test_image_create_already_exists(self):
         """Tests proper exception is raised if image with ID already exists"""
-        fixture = {
-            'id': UUID2,
-            'name': 'fake public image',
-            'is_public': True,
-            'disk_format': 'vmdk',
-            'container_format': 'ovf',
-            'size': 19,
-            'status': 'active',
-            'location': "file:///tmp/glance-tests/2",
-        }
+        fixture = self.get_fixture(id=UUID2,
+                                   location="file:///tmp/glance-tests/2")
 
         self.assertRaises(exception.Duplicate,
                           self.client.image_create,
@@ -673,15 +447,8 @@ class TestRegistryV2Client(base.IsolatedUnitTest):
 
     def test_image_create_with_bad_status(self):
         """Tests proper exception is raised if a bad status is set"""
-        fixture = {
-            'name': 'fake public image',
-            'is_public': True,
-            'disk_format': 'vmdk',
-            'container_format': 'ovf',
-            'status': 'bad status',
-            'size': 19,
-            'location': "file:///tmp/glance-tests/2",
-        }
+        fixture = self.get_fixture(status='bad status',
+                                   location="file:///tmp/glance-tests/2")
 
         self.assertRaises(exception.Invalid,
                           self.client.image_create,
@@ -703,13 +470,7 @@ class TestRegistryV2Client(base.IsolatedUnitTest):
 
     def test_image_update_not_existing(self):
         """Tests non existing image update doesn't work"""
-        fixture = {
-            'name': 'fake public image',
-            'is_public': True,
-            'disk_format': 'vmdk',
-            'container_format': 'ovf',
-            'status': 'bad status',
-        }
+        fixture = self.get_fixture(status='bad status')
 
         self.assertRaises(exception.NotFound,
                           self.client.image_update,
@@ -807,16 +568,20 @@ class TestRegistryV2ClientApi(base.IsolatedUnitTest):
         rapi.configure_registry_client()
         self.mox.VerifyAll()
 
-    def test_configure_registry_admin_creds(self):
-        expected = {
+    def _get_fake_config_creds(self, auth_url='auth_url', strategy='keystone'):
+        return {
             'user': 'user',
             'password': 'password',
             'username': 'user',
             'tenant': 'tenant',
-            'auth_url': None,
-            'strategy': 'configured_strategy',
-            'region': 'region',
+            'auth_url': auth_url,
+            'strategy': strategy,
+            'region': 'region'
         }
+
+    def test_configure_registry_admin_creds(self):
+        expected = self._get_fake_config_creds(auth_url=None,
+                                               strategy='configured_strategy')
         self.config(admin_user=expected['user'])
         self.config(admin_password=expected['password'])
         self.config(admin_tenant_name=expected['tenant'])
@@ -829,15 +594,7 @@ class TestRegistryV2ClientApi(base.IsolatedUnitTest):
         self.assertEquals(rapi._CLIENT_CREDS, expected)
 
     def test_configure_registry_admin_creds_with_auth_url(self):
-        expected = {
-            'user': 'user',
-            'password': 'password',
-            'username': 'user',
-            'tenant': 'tenant',
-            'auth_url': 'auth_url',
-            'strategy': 'keystone',
-            'region': 'region',
-        }
+        expected = self._get_fake_config_creds()
         self.config(admin_user=expected['user'])
         self.config(admin_password=expected['password'])
         self.config(admin_tenant_name=expected['tenant'])
